const fs=require('fs');

class Froggier{
  constructor(){
    this.startingKeyword="{(:";
    this.endingKeyword=":)}";
  }

  /**
    * Synchronous

    * Replaces variables in the HTML file with some values

    * @param {string} filename filename : Path of the HTML file. Example file path: `views/home.html` , Example file content: `<p>{(:text:)}</p>`
    * @param {object} data data : A JSON object with keys as the variables and values as the text to be replaced. Example JSON: `{"text":"Hi!"}`

    * @info See `.renderSync()` in package README file for more information - https://www.npmjs.com/package/froggier
  */
  renderSync(filename,data){
    var key=Object.keys(data);
    var file=fs.readFileSync(filename,'utf-8');
    var index=0;
    var value;
    while (index<key.length){
      value=data[key[index]];
      var htmlkey=this.startingKeyword+key[index]+this.endingKeyword;
      console.log(htmlkey)
      if (file.includes(htmlkey)){
        var occurence=file.split(htmlkey).length;
        var index2=0;
        while (index2<occurence){
          file=file.replace(htmlkey,value);
          index2++;
        }
      }
      index++;
    }
    return file;
  }

  /**
    * Asynchronous

    * Replaces variables in the HTML file with some values

    * @param {string} filename filename : Path of the HTML file. Example file path: `views/home.html` , Example file content: `<p>{(:text:)}</p>`
    * @param {object} data data : A JSON object with keys as the variables and values as the text to be replaced. Example JSON: `{"text":"Hi!"}`

    * @info See `.render()` in package README file for more information - https://www.npmjs.com/package/froggier
  */
  async render(filename,data){
      var key=Object.keys(data);
      var res;
      fs.readFile(filename,'utf8',(err,file)=>{
        var index=0;
        var value;
        while (index<key.length){
          value=data[key[index]];
          var htmlkey=this.startingKeyword+key[index]+this.endingKeyword;
          if (file.includes(htmlkey)){
            var occurence=file.split(htmlkey).length;
            var index2=0;
            while (index2<occurence){
              file=file.replace(htmlkey,value);
              index2++;
            }
          }
          index++;
        }
        res=file;
      })

      return new Promise(resolve=>{setTimeout(()=>{resolve(res)},50)})
    }
  }

module.exports=new Froggier;